@@ -27,20 +27,28 @@ int main(int argc, char *argv[])
     SingleApp scr(argc, argv, QStringLiteral(VERSION));
     scr.setApplicationVersion(QStringLiteral(VERSION));
     scr.setOrganizationName(QStringLiteral("lxqt"));
-    scr.setOrganizationDomain(QStringLiteral("https://lxqt.org"));
+    scr.setOrganizationDomain(QStringLiteral("lxqt-project.org"));
     scr.setApplicationName(QStringLiteral("screengrab"));
+    scr.setDesktopFileName(QStringLiteral("screengrab"));
     Core *ScreenGrab = Core::instance();
-    ScreenGrab->modules()->initModules();
     ScreenGrab->processCmdLineOpts(scr.arguments());
-
-    QObject::connect(&scr, &SingleApp::messageReceived, ScreenGrab, &Core::initWindow);
+    // SingleApp should be initialized only after processing command-line options
+    // because otherwise, if the help or version option is given, the app will
+    // exit suddenly, without clearing the shared memory.
+    scr.init();
 
     if (!ScreenGrab->config()->getAllowMultipleInstance() && scr.isRunning())
     {
+        // Send a message to the current instance and exit.
         QString type = QString::number(ScreenGrab->config()->getDefScreenshotType());
         scr.sendMessage(QStringLiteral("screengrab --type=") + type);
         return 0;
     }
 
+    // Initialize the modules as well as the window and listen to messages.
+    ScreenGrab->modules()->initModules();
+    ScreenGrab->initWindow();
+    QObject::connect(&scr, &SingleApp::messageReceived, ScreenGrab, &Core::initWindow);
+
     return scr.exec();
 }
